This is a convenience function that provides a simple way to call
startServer(), service(), and
stopServer() in the correct sequence. It does not return unless
interrupted or an error occurs.
Arguments
- host
A string that is a valid IPv4 or IPv6 address that is owned by this server, which the application will listen on.
"0.0.0.0"represents all IPv4 addresses and"::/0"represents all IPv6 addresses.- port
A number or integer that indicates the server port that should be listened on. Note that on most Unix-like systems including Linux and macOS, port numbers smaller than 1024 require root privileges.
- app
A collection of functions that define your application. See
startServer().- interruptIntervalMs
Deprecated (last used in httpuv 1.3.5).
Details
If you have multiple hosts and/or ports to listen on, call the individual
functions instead of runServer.