This will stop all applications which were created by
startServer() or startPipeServer().
See also
stopServer() to stop a specific server.
This will stop all applications which were created by
startServer() or startPipeServer().
stopServer() to stop a specific server.