Skip to contents

This function will be removed in a future release of httpuv. Instead, use stopServer().

Usage

stopDaemonizedServer(server)

Arguments

server

A server object that was previously returned from startServer() or startPipeServer().