This class represents a server running one application that listens on a named pipe.
See also
Server() and WebServer().
Super class
httpuv::Server -> PipeServer
Methods
Method new()
Initialize a new PipeServer object
Create a new PipeServer object. app is an httpuv application
object as described in startServer().
Usage
PipeServer$new(name, mask, app, quiet = FALSE)Arguments
nameThe name of the named pipe to bind the server to.
maskThe mask for the named pipe. If NULL, it defaults to -1.
appAn httpuv application object as described in
startServer().quietIf TRUE, suppresses output from the server.
Examples
## ------------------------------------------------
## Method `PipeServer$new`
## ------------------------------------------------
if (FALSE) { # \dontrun{
# Create a simple app
app <- function(req) {
list(
status = 200L,
headers = list('Content-Type' = 'text/plain'),
body = "Hello, world!"
)
}
# Create a server
server <- PipeServer$new("my_pipe", -1, app)
} # }