Stop a running daemonized server in Unix environments (deprecated)
Source:R/server.R
stopDaemonizedServer.RdThis function will be removed in a future release of httpuv. Instead, use
stopServer().
Arguments
- server
A server object that was previously returned from
startServer()orstartPipeServer().