Given a server object that was returned from a previous invocation of
startServer() or startPipeServer(), this closes all
open connections for that server and unbinds the port.
Arguments
- server
A server object that was previously returned from
startServer()orstartPipeServer().
See also
stopAllServers() to stop all servers.